

## Novigi Custom Airflow Operators ,hooks and plugins ##

* This Repo mainly contains custom airflow operators and hooks which were writen by Novigi Pty Ltd 
* Version No - 1.0.2
* Bitbucket Link - https://bitbucket.org/novigi/nov20011-airflow-common-extensions/src/master/


### How do I get set up? ###

* Open a terminal and just type "sudo pip install novigi_common"
* You can import them into your project as 
          from novigi_common.<operators/hoooks/custom_plugings>.<file name> import <class name>

### Who do I talk to? ###

* integration@novigi.com.au
